@@ -340,7 +340,7 @@ def apply_styles(x: List[int], styles: List[str], **kwargs):
 
 def _check_duration(total_time, duration):
     if duration:
-        if duration >= max:
+        if duration >= total_time:
             return True
     return False
 
